==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/InternetGateway.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin

import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [InternetGateway].
 */
@PulumiTagMarker
public class InternetGatewayResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: InternetGatewayArgs = InternetGatewayArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend InternetGatewayArgsBuilder.() -> Unit) {
        val builder = InternetGatewayArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): InternetGateway {
        val builtJavaResource =
            com.pulumi.azurenative.managednetworkfabric.InternetGateway(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return InternetGateway(builtJavaResource)
    }
}

/**
 * The Internet Gateway resource definition.
 * Azure REST API version: 2023-06-15.
 * ## Example Usage
 * ### InternetGateways_Create_MaximumSet_Gen
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var internetGateway = new AzureNative.ManagedNetworkFabric.InternetGateway("internetGateway", new()
 *     {
 *         Annotation = "annotation",
 *         InternetGatewayName = "example-internetGateway",
 *         InternetGatewayRuleId = "/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule",
 *         Location = "eastus",
 *         NetworkFabricControllerId = "/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController",
 *         ResourceGroupName = "example-rg",
 *         Tags =
 *         {
 *             { "key3540", "1234" },
 *         },
 *         Type = "Infrastructure",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/managednetworkfabric/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := managednetworkfabric.NewInternetGateway(ctx, "internetGateway", &managednetworkfabric.InternetGatewayArgs{
 * 			Annotation:                pulumi.String("annotation"),
 * 			InternetGatewayName:       pulumi.String("example-internetGateway"),
 * 			InternetGatewayRuleId:     pulumi.String("/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule"),
 * 			Location:                  pulumi.String("eastus"),
 * 			NetworkFabricControllerId: pulumi.String("/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController"),
 * 			ResourceGroupName:         pulumi.String("example-rg"),
 * 			Tags: pulumi.StringMap{
 * 				"key3540": pulumi.String("1234"),
 * 			},
 * 			Type: pulumi.String("Infrastructure"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.managednetworkfabric.InternetGateway;
 * import com.pulumi.azurenative.managednetworkfabric.InternetGatewayArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var internetGateway = new InternetGateway("internetGateway", InternetGatewayArgs.builder()
 *             .annotation("annotation")
 *             .internetGatewayName("example-internetGateway")
 *             .internetGatewayRuleId("/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule")
 *             .location("eastus")
 *             .networkFabricControllerId("/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController")
 *             .resourceGroupName("example-rg")
 *             .tags(Map.of("key3540", "1234"))
 *             .type("Infrastructure")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:managednetworkfabric:InternetGateway example-internetGateway /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedNetworkFabric/internetGateways/{internetGatewayName}
 * ```
 */
public class InternetGateway internal constructor(
    override val javaResource: com.pulumi.azurenative.managednetworkfabric.InternetGateway,
) : KotlinCustomResource(javaResource, InternetGatewayMapper) {
    /**
     * Switch configuration description.
     */
    public val `annotation`: Output<String>?
        get() = javaResource.`annotation`().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * ARM Resource ID of the Internet Gateway Rule.
     */
    public val internetGatewayRuleId: Output<String>?
        get() = javaResource.internetGatewayRuleId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * IPv4 Address of Internet Gateway.
     */
    public val ipv4Address: Output<String>
        get() = javaResource.ipv4Address().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * ARM Resource ID of the Network Fabric Controller.
     */
    public val networkFabricControllerId: Output<String>
        get() = javaResource.networkFabricControllerId().applyValue({ args0 -> args0 })

    /**
     * Port number of Internet Gateway.
     */
    public val port: Output<Int>
        get() = javaResource.port().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object InternetGatewayMapper : ResourceMapper<InternetGateway> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.managednetworkfabric.InternetGateway::class == javaResource::class

    override fun map(javaResource: Resource): InternetGateway = InternetGateway(
        javaResource as
            com.pulumi.azurenative.managednetworkfabric.InternetGateway,
    )
}

/**
 * @see [InternetGateway].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [InternetGateway].
 */
public suspend fun internetGateway(
    name: String,
    block: suspend InternetGatewayResourceBuilder.() -> Unit,
): InternetGateway {
    val builder = InternetGatewayResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [InternetGateway].
 * @param name The _unique_ name of the resulting resource.
 */
public fun internetGateway(name: String): InternetGateway {
    val builder = InternetGatewayResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/InternetGateway.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin

import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [InternetGateway].
 */
@PulumiTagMarker
public class InternetGatewayResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: InternetGatewayArgs = InternetGatewayArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend InternetGatewayArgsBuilder.() -> Unit) {
        val builder = InternetGatewayArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): InternetGateway {
        val builtJavaResource =
            com.pulumi.azurenative.managednetworkfabric.InternetGateway(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return InternetGateway(builtJavaResource)
    }
}

/**
 * The Internet Gateway resource definition.
 * Azure REST API version: 2023-06-15.
 * ## Example Usage
 * ### InternetGateways_Create_MaximumSet_Gen
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var internetGateway = new AzureNative.ManagedNetworkFabric.InternetGateway("internetGateway", new()
 *     {
 *         Annotation = "annotation",
 *         InternetGatewayName = "example-internetGateway",
 *         InternetGatewayRuleId = "/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule",
 *         Location = "eastus",
 *         NetworkFabricControllerId = "/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController",
 *         ResourceGroupName = "example-rg",
 *         Tags =
 *         {
 *             { "key3540", "1234" },
 *         },
 *         Type = AzureNative.ManagedNetworkFabric.GatewayType.Infrastructure,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/managednetworkfabric/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := managednetworkfabric.NewInternetGateway(ctx, "internetGateway", &managednetworkfabric.InternetGatewayArgs{
 * 			Annotation:                pulumi.String("annotation"),
 * 			InternetGatewayName:       pulumi.String("example-internetGateway"),
 * 			InternetGatewayRuleId:     pulumi.String("/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule"),
 * 			Location:                  pulumi.String("eastus"),
 * 			NetworkFabricControllerId: pulumi.String("/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController"),
 * 			ResourceGroupName:         pulumi.String("example-rg"),
 * 			Tags: pulumi.StringMap{
 * 				"key3540": pulumi.String("1234"),
 * 			},
 * 			Type: pulumi.String(managednetworkfabric.GatewayTypeInfrastructure),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.managednetworkfabric.InternetGateway;
 * import com.pulumi.azurenative.managednetworkfabric.InternetGatewayArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var internetGateway = new InternetGateway("internetGateway", InternetGatewayArgs.builder()
 *             .annotation("annotation")
 *             .internetGatewayName("example-internetGateway")
 *             .internetGatewayRuleId("/subscriptions/xxxx-xxxx-xxxx-xxxx/providers/Microsoft.ManagedNetworkFabric/internetGatewayRules/example-internetGatewayRule")
 *             .location("eastus")
 *             .networkFabricControllerId("/subscriptions/xxxx-xxxx-xxxx-xxxx/resourcegroups/example-rg/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/example-networkFabricController")
 *             .resourceGroupName("example-rg")
 *             .tags(Map.of("key3540", "1234"))
 *             .type("Infrastructure")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:managednetworkfabric:InternetGateway example-internetGateway /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedNetworkFabric/internetGateways/{internetGatewayName}
 * ```
 */
public class InternetGateway internal constructor(
    override val javaResource: com.pulumi.azurenative.managednetworkfabric.InternetGateway,
) : KotlinCustomResource(javaResource, InternetGatewayMapper) {
    /**
     * Switch configuration description.
     */
    public val `annotation`: Output<String>?
        get() = javaResource.`annotation`().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * ARM Resource ID of the Internet Gateway Rule.
     */
    public val internetGatewayRuleId: Output<String>?
        get() = javaResource.internetGatewayRuleId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * IPv4 Address of Internet Gateway.
     */
    public val ipv4Address: Output<String>
        get() = javaResource.ipv4Address().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * ARM Resource ID of the Network Fabric Controller.
     */
    public val networkFabricControllerId: Output<String>
        get() = javaResource.networkFabricControllerId().applyValue({ args0 -> args0 })

    /**
     * Port number of Internet Gateway.
     */
    public val port: Output<Int>
        get() = javaResource.port().applyValue({ args0 -> args0 })

    /**
     * Provisioning state of resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object InternetGatewayMapper : ResourceMapper<InternetGateway> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.managednetworkfabric.InternetGateway::class == javaResource::class

    override fun map(javaResource: Resource): InternetGateway = InternetGateway(
        javaResource as
            com.pulumi.azurenative.managednetworkfabric.InternetGateway,
    )
}

/**
 * @see [InternetGateway].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [InternetGateway].
 */
public suspend fun internetGateway(
    name: String,
    block: suspend InternetGatewayResourceBuilder.() -> Unit,
): InternetGateway {
    val builder = InternetGatewayResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [InternetGateway].
 * @param name The _unique_ name of the resulting resource.
 */
public fun internetGateway(name: String): InternetGateway {
    val builder = InternetGatewayResourceBuilder()
    builder.name(name)
    return builder.build()
}
